var group__types_group =
[
    [ "__natsClientConfig", "struct____nats_client_config.html", [
      [ "DefaultWriteDeadline", "struct____nats_client_config.html#a9a92a915d00d9f39592c407ad6b4a5d1", null ],
      [ "LockSpinCount", "struct____nats_client_config.html#aa8e7db4bae066739c5af59a93d6b4ca0", null ],
      [ "DefaultToThreadPool", "struct____nats_client_config.html#a9cfade80f1a92d2ce6821007a282d047", null ],
      [ "ThreadPoolMax", "struct____nats_client_config.html#a7c9592d371e589faf41d5f493934b5c1", null ],
      [ "DefaultRepliesToThreadPool", "struct____nats_client_config.html#a053db33a66e585ee3d5c4f9689db63bf", null ],
      [ "UseSeparatePoolForReplies", "struct____nats_client_config.html#a11769afbb1dd577e63571e05fd579ddf", null ],
      [ "ReplyThreadPoolMax", "struct____nats_client_config.html#a70f9a7d726a564fb1c3ef14c1bc6cd47", null ]
    ] ],
    [ "natsMsgList", "structnats_msg_list.html", [
      [ "Msgs", "structnats_msg_list.html#aa123668879f1c9c11c9be7bd81a205c5", null ],
      [ "Count", "structnats_msg_list.html#a5c48bf6b9e7f1d889d7ad31694911750", null ]
    ] ],
    [ "natsMetadata", "structnats_metadata.html", [
      [ "List", "structnats_metadata.html#af29f95d80bf99ab77601518b143b1dd5", null ],
      [ "Count", "structnats_metadata.html#a5412b3c7d4c67cc45f8d27df25851411", null ]
    ] ],
    [ "jsPubOptions", "structjs_pub_options.html", [
      [ "MaxWait", "structjs_pub_options.html#a1b242c9311b904a2e5337417b5c6d143", null ],
      [ "MsgId", "structjs_pub_options.html#ac8708487360b784f7dd5d7a21e5617c0", null ],
      [ "ExpectStream", "structjs_pub_options.html#ac7ac74d2557d772c3092288dacf3711f", null ],
      [ "ExpectLastMsgId", "structjs_pub_options.html#a095391b33a261586fc02eaf013b65e61", null ],
      [ "ExpectLastSeq", "structjs_pub_options.html#a3b02b60b05caa6d242079a4c26b181bf", null ],
      [ "ExpectLastSubjectSeq", "structjs_pub_options.html#aeefec1d2c7644562d23b87e55bf2e253", null ],
      [ "ExpectNoMessage", "structjs_pub_options.html#a740a7edee8c832a75b75fded6046ba90", null ]
    ] ],
    [ "jsPlacement", "structjs_placement.html", [
      [ "Cluster", "structjs_placement.html#ad8c83588d57f0e30959cfb6f3d5d61bf", null ],
      [ "Tags", "structjs_placement.html#af078a85b744b9ff3771bb2da6005b90d", null ],
      [ "TagsLen", "structjs_placement.html#a35644f07531409518521b1b4fa28c9e3", null ]
    ] ],
    [ "jsExternalStream", "structjs_external_stream.html", [
      [ "APIPrefix", "structjs_external_stream.html#a2eaf2c0c3e77c269f44e254af8b24e96", null ],
      [ "DeliverPrefix", "structjs_external_stream.html#a26ca427f3c5be1cae579ddccc16432d3", null ]
    ] ],
    [ "jsStreamSource", "structjs_stream_source.html", [
      [ "Name", "structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3", null ],
      [ "OptStartSeq", "structjs_stream_source.html#ad6948b7a34c202f324b6d2beb32fe5ed", null ],
      [ "OptStartTime", "structjs_stream_source.html#a67eb1dac41b2d826a923cfb23baa24a5", null ],
      [ "FilterSubject", "structjs_stream_source.html#af787b51dde9d77626f33860564eb08c3", null ],
      [ "External", "structjs_stream_source.html#a295458d156af5373bb3f5ab06612a888", null ],
      [ "Domain", "structjs_stream_source.html#aa304239ee823ef87fcb53ebb0c077e7b", null ]
    ] ],
    [ "jsRePublish", "structjs_re_publish.html", [
      [ "Source", "structjs_re_publish.html#a1acb593929fd69bbe0f4dc8300dfaeb2", null ],
      [ "Destination", "structjs_re_publish.html#a662b2e57d237b171b2b61509f7e1023a", null ],
      [ "HeadersOnly", "structjs_re_publish.html#a16ebc4cdae4a407cf4e32aad212888db", null ]
    ] ],
    [ "jsSubjectTransformConfig", "structjs_subject_transform_config.html", [
      [ "Source", "structjs_subject_transform_config.html#a88f31069ce9bb75bcd8c34c32a204299", null ],
      [ "Destination", "structjs_subject_transform_config.html#a17ccd4ff50cbfdc3e077ea76fa1f0720", null ]
    ] ],
    [ "jsStreamConsumerLimits", "structjs_stream_consumer_limits.html", [
      [ "InactiveThreshold", "structjs_stream_consumer_limits.html#aaf4fdc51f35f27690c05c410d185e5d1", null ],
      [ "MaxAckPending", "structjs_stream_consumer_limits.html#a04a6c89366cf75dbf76e43c786b133a4", null ]
    ] ],
    [ "jsStreamConfig", "structjs_stream_config.html", [
      [ "Name", "structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5", null ],
      [ "Description", "structjs_stream_config.html#a4f9f422d2e9e7389860291ab19bd7f10", null ],
      [ "Subjects", "structjs_stream_config.html#a0c5f3354073dbe72650e3db7f59a47af", null ],
      [ "SubjectsLen", "structjs_stream_config.html#ab2186aae798df6c222b3fa69e31597e1", null ],
      [ "Retention", "structjs_stream_config.html#a5ebc95b76afafa5e7a129953ba1bb3c7", null ],
      [ "MaxConsumers", "structjs_stream_config.html#a7338c82c8cbfcd5f4bfb7ad34b1d8395", null ],
      [ "MaxMsgs", "structjs_stream_config.html#a60a5184d1d97b056dbb31ac6a5b3d82d", null ],
      [ "MaxBytes", "structjs_stream_config.html#ad75e47d4293441bd5ddbc5eaf01e0451", null ],
      [ "MaxAge", "structjs_stream_config.html#aa538765ad97d343d60212ebd9894661e", null ],
      [ "MaxMsgsPerSubject", "structjs_stream_config.html#aa167c7547d13bf2a01510a375ad38340", null ],
      [ "MaxMsgSize", "structjs_stream_config.html#a93a2336a57b6bfb792d530fd13a90641", null ],
      [ "Discard", "structjs_stream_config.html#a0b44ea5251ef20bf5b5658bcfbea832d", null ],
      [ "Storage", "structjs_stream_config.html#a59c34091f336eafa77da2991c852c0d8", null ],
      [ "Replicas", "structjs_stream_config.html#adbf2c948cf8091b149603b918ef49ffc", null ],
      [ "NoAck", "structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609", null ],
      [ "Template", "structjs_stream_config.html#a50f866f0e73c4ff0a5f43b354a059fa9", null ],
      [ "Duplicates", "structjs_stream_config.html#a9e0ff10273d0182f885615b4f7d1cc20", null ],
      [ "Placement", "structjs_stream_config.html#acee6c66afc78d79c2f518eed89177efb", null ],
      [ "Mirror", "structjs_stream_config.html#acdba5b22e4e60fd81a54769a7d09bc51", null ],
      [ "Sources", "structjs_stream_config.html#a8f0ee08922e5b2108082b5b9e4a6284b", null ],
      [ "SourcesLen", "structjs_stream_config.html#a34960d6acc710c2f32b563f4bb7c9c0a", null ],
      [ "Sealed", "structjs_stream_config.html#aede3fd2ab13d230eda14c96f9997e1b7", null ],
      [ "DenyDelete", "structjs_stream_config.html#af2d42dd29b9a35257937aeeb53c9f287", null ],
      [ "DenyPurge", "structjs_stream_config.html#a575ffbaa85b0300032963296b090583a", null ],
      [ "AllowRollup", "structjs_stream_config.html#aba71cdb342181f52bb9f7ff5f770a1fa", null ],
      [ "RePublish", "structjs_stream_config.html#a95ab0061b6e935b129a4a9c133e6b11c", null ],
      [ "AllowDirect", "structjs_stream_config.html#a28630f6f07ca02553c5d5718d7c29721", null ],
      [ "MirrorDirect", "structjs_stream_config.html#a9d67ddcc7c54c345dd60ed5e59234f1e", null ],
      [ "DiscardNewPerSubject", "structjs_stream_config.html#a3fb7d5e1a09829fe742749da880afe4a", null ],
      [ "Metadata", "structjs_stream_config.html#a7aa4849b0f555c9de6b6da953929a565", null ],
      [ "Compression", "structjs_stream_config.html#a406554aaf1e16eed4abade52f7ca5e61", null ],
      [ "FirstSeq", "structjs_stream_config.html#a7ed5e8e5a8d367b25751b9708d0e395b", null ],
      [ "SubjectTransform", "structjs_stream_config.html#a0ce1d0a7c1f0576151f505724ae393d1", null ],
      [ "ConsumerLimits", "structjs_stream_config.html#a5ce51cb5a36febda30bb444a0f59c2d1", null ]
    ] ],
    [ "jsLostStreamData", "structjs_lost_stream_data.html", [
      [ "Msgs", "structjs_lost_stream_data.html#a5d2e87697526033c842a7f955776dfda", null ],
      [ "MsgsLen", "structjs_lost_stream_data.html#abdc373ed7fc9b7cf161c13da1913fc9a", null ],
      [ "Bytes", "structjs_lost_stream_data.html#a841fcadca3f66e9170a51080dc1acf30", null ]
    ] ],
    [ "jsStreamStateSubject", "structjs_stream_state_subject.html", [
      [ "Subject", "structjs_stream_state_subject.html#aa766824a7f8b69db592971af3262640e", null ],
      [ "Msgs", "structjs_stream_state_subject.html#a8b9b2edc5afe82b7b3bc7dbdd67a4384", null ]
    ] ],
    [ "jsStreamStateSubjects", "structjs_stream_state_subjects.html", [
      [ "List", "structjs_stream_state_subjects.html#aef3d1e886b16961daa84c43650fa80c0", null ],
      [ "Count", "structjs_stream_state_subjects.html#ab88e2026f518b6cdffd3901b5e5cd374", null ]
    ] ],
    [ "jsStreamState", "structjs_stream_state.html", [
      [ "Msgs", "structjs_stream_state.html#a495269fe83c6bbf2023cca94add0a888", null ],
      [ "Bytes", "structjs_stream_state.html#ae603fa6ecfb63c93b61272b7d1b8fb4d", null ],
      [ "FirstSeq", "structjs_stream_state.html#a55bb6719163acef7fdb6d0bc3ae8d5da", null ],
      [ "FirstTime", "structjs_stream_state.html#afb7a708022faff518c060b33e99b04b0", null ],
      [ "LastSeq", "structjs_stream_state.html#a22da809fe7a1ec3101841e86d6708827", null ],
      [ "LastTime", "structjs_stream_state.html#a67cbd0d8b43d8c05c8b4cd6b0e44dab0", null ],
      [ "NumSubjects", "structjs_stream_state.html#aaa43db17641826e7c6ecc1954f641960", null ],
      [ "Subjects", "structjs_stream_state.html#a4af56e8bee7262ab050f2a25114c5909", null ],
      [ "NumDeleted", "structjs_stream_state.html#acbec2f01830b56cb4c0bf54ae5170e51", null ],
      [ "Deleted", "structjs_stream_state.html#abcf4d3c581c06d820f1ad21d640bef3f", null ],
      [ "DeletedLen", "structjs_stream_state.html#a34a08a64c97269165630bf2e0c78c2c0", null ],
      [ "Lost", "structjs_stream_state.html#a1adf8991f31fc4db9d6907a0316f8eec", null ],
      [ "Consumers", "structjs_stream_state.html#a27f4cfb85c0f1b0c5c7ad5275bd25d85", null ]
    ] ],
    [ "jsPeerInfo", "structjs_peer_info.html", [
      [ "Name", "structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a", null ],
      [ "Current", "structjs_peer_info.html#ad8cecd039a8ad1c68daba89007b055d4", null ],
      [ "Offline", "structjs_peer_info.html#a3f3e09c5996858ec5faca2dc7fa5224e", null ],
      [ "Active", "structjs_peer_info.html#a8441d023932c388953197f7ea39402fe", null ],
      [ "Lag", "structjs_peer_info.html#a49a2623963dad653a6d7996c750056c9", null ]
    ] ],
    [ "jsClusterInfo", "structjs_cluster_info.html", [
      [ "Name", "structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484", null ],
      [ "Leader", "structjs_cluster_info.html#af7d85652b52f56fa1eedce8f45fe6a19", null ],
      [ "Replicas", "structjs_cluster_info.html#a8dfcae3bc348a5b595b509e3f3d3500b", null ],
      [ "ReplicasLen", "structjs_cluster_info.html#a237a639579def1345e02f1490a510ed5", null ]
    ] ],
    [ "jsStreamSourceInfo", "structjs_stream_source_info.html", [
      [ "Name", "structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04", null ],
      [ "External", "structjs_stream_source_info.html#a7eb19dd2637079fd1e970a2b38d33e05", null ],
      [ "Lag", "structjs_stream_source_info.html#ab2ee0ca3ecd98c2df6d4e9bd88686863", null ],
      [ "Active", "structjs_stream_source_info.html#a28b8cc0a9d487672955d3a3fa03de247", null ],
      [ "FilterSubject", "structjs_stream_source_info.html#a0c0f08cd9dc97a5df116356bfebb8824", null ],
      [ "SubjectTransforms", "structjs_stream_source_info.html#ad16f78fb770402bf3a2e15387b02e7da", null ],
      [ "SubjectTransformsLen", "structjs_stream_source_info.html#a6c150fb59dd91a954e0877937a5498d5", null ]
    ] ],
    [ "jsStreamAlternate", "structjs_stream_alternate.html", [
      [ "Name", "structjs_stream_alternate.html#a07f36f98c7dcdf435f803e4f0ccaac57", null ],
      [ "Domain", "structjs_stream_alternate.html#a7c25ab1a427b78c4e1ba58ff7cdb5a8f", null ],
      [ "Cluster", "structjs_stream_alternate.html#a3e85014d03dd425435ed5a0b6a5dfb1d", null ]
    ] ],
    [ "jsStreamInfo", "structjs_stream_info.html", [
      [ "Config", "structjs_stream_info.html#adcc402d28e0ee443419e9b549da233c6", null ],
      [ "Created", "structjs_stream_info.html#a578ce52a275c690dd4627c1d119c7838", null ],
      [ "State", "structjs_stream_info.html#a766ac56dec3bd19fa5b9861fb5f64397", null ],
      [ "Cluster", "structjs_stream_info.html#a8d10d6fdc3f713ac726c72cae06a209a", null ],
      [ "Mirror", "structjs_stream_info.html#ab71aae7e4f6c62e2a09a3a52c9e4fa2a", null ],
      [ "Sources", "structjs_stream_info.html#a2e7ca48a93fe57265609e7e0cd3fa386", null ],
      [ "SourcesLen", "structjs_stream_info.html#af14110cb1f8e16e3dade8d9f7c2fd672", null ],
      [ "Alternates", "structjs_stream_info.html#a720c4ff9090bafda50000843810ab1bb", null ],
      [ "AlternatesLen", "structjs_stream_info.html#ad37a5fd700bd5df54e5002c7de51c3ad", null ]
    ] ],
    [ "jsStreamInfoList", "structjs_stream_info_list.html", [
      [ "List", "structjs_stream_info_list.html#a7b096ee7a25363f231f56419a244daef", null ],
      [ "Count", "structjs_stream_info_list.html#a8bc8490af12bb4f7a245605aecde62c2", null ]
    ] ],
    [ "jsStreamNamesList", "structjs_stream_names_list.html", [
      [ "List", "structjs_stream_names_list.html#a1875a7e449759dfc2a40b0eb74de0acf", null ],
      [ "Count", "structjs_stream_names_list.html#ab1385b6333537306d0462946c26cde4f", null ]
    ] ],
    [ "jsConsumerConfig", "structjs_consumer_config.html", [
      [ "Name", "structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a", null ],
      [ "Durable", "structjs_consumer_config.html#a36cf121162cf0b40edf051991d851ee0", null ],
      [ "Description", "structjs_consumer_config.html#a36a14d666d99bdade87a5e21a25491d6", null ],
      [ "DeliverPolicy", "structjs_consumer_config.html#a364127e68bf0d3bf13efdc0b416667f4", null ],
      [ "OptStartSeq", "structjs_consumer_config.html#a2f0243899885dc97f304f48ca52b5356", null ],
      [ "OptStartTime", "structjs_consumer_config.html#a802ea3bf0669395bee28611f4ecede80", null ],
      [ "AckPolicy", "structjs_consumer_config.html#a8a311af614dfae1b0f4e4af7db467aab", null ],
      [ "AckWait", "structjs_consumer_config.html#a651a94b9b78668dde830dc7869610e67", null ],
      [ "MaxDeliver", "structjs_consumer_config.html#ad47e15e1d6a4a8b0b155f9d3d5873c95", null ],
      [ "BackOff", "structjs_consumer_config.html#aa2d0aff64a2c46122d0f0fe89e8ae011", null ],
      [ "BackOffLen", "structjs_consumer_config.html#ad2f6ca3f2d0f977aedb8687c462c1cfc", null ],
      [ "FilterSubject", "structjs_consumer_config.html#af56ab7708b11e85e0b9115d152d281ca", null ],
      [ "ReplayPolicy", "structjs_consumer_config.html#ade510daf7c5d67553d2cd20b64ab9939", null ],
      [ "RateLimit", "structjs_consumer_config.html#a351b388a36ccb7978e6e85a6f4fc0816", null ],
      [ "SampleFrequency", "structjs_consumer_config.html#a43f40b8eef0074b4146fb945b4645584", null ],
      [ "MaxWaiting", "structjs_consumer_config.html#a8472d49fae908ab0291b4d62c8411b76", null ],
      [ "MaxAckPending", "structjs_consumer_config.html#aeb2336d480e3885385d1b08410e89892", null ],
      [ "FlowControl", "structjs_consumer_config.html#a484c64b6c54f6f758f54315470ed20d0", null ],
      [ "Heartbeat", "structjs_consumer_config.html#ac439828c3bedb8826a1e92de13280d53", null ],
      [ "HeadersOnly", "structjs_consumer_config.html#a30d4142bac47ab6dc583c5ee193704e6", null ],
      [ "MaxRequestBatch", "structjs_consumer_config.html#a4e86deefe08854b9a82b4908397aad32", null ],
      [ "MaxRequestExpires", "structjs_consumer_config.html#aa71aa3dfe5826466be301097b1bae04d", null ],
      [ "MaxRequestMaxBytes", "structjs_consumer_config.html#a74a026cdd92c538bcf84297f4468bb21", null ],
      [ "DeliverSubject", "structjs_consumer_config.html#a95aa4184ed77f69b7674756572da1ded", null ],
      [ "DeliverGroup", "structjs_consumer_config.html#ae0765f3b5effe365187d3cf809c6ed3c", null ],
      [ "InactiveThreshold", "structjs_consumer_config.html#af6376a6009124c25d7016bc548f3855d", null ],
      [ "Replicas", "structjs_consumer_config.html#acfba6d6ecb6323fd8ffe6c0bb4fbffae", null ],
      [ "MemoryStorage", "structjs_consumer_config.html#a046177256938d6a601c629f9fd82f888", null ],
      [ "FilterSubjects", "structjs_consumer_config.html#ada703eb1db0288d8a937126d6d856c6f", null ],
      [ "FilterSubjectsLen", "structjs_consumer_config.html#a2a6cdec5efe7542496f8b8cccb539643", null ],
      [ "Metadata", "structjs_consumer_config.html#a8bfc0284c57028bf9cf809205d989959", null ],
      [ "PauseUntil", "structjs_consumer_config.html#acf04468ef0a8bc4e83912e850e47a8ae", null ]
    ] ],
    [ "jsConsumerSequenceMismatch", "structjs_consumer_sequence_mismatch.html", [
      [ "Stream", "structjs_consumer_sequence_mismatch.html#aad6a17af1719c023c38a6fd254b73f8e", null ],
      [ "ConsumerClient", "structjs_consumer_sequence_mismatch.html#adb383429dadb1ab0e1f7d013bc546a28", null ],
      [ "ConsumerServer", "structjs_consumer_sequence_mismatch.html#ac1df353001d853c8a56cef9f82fb831c", null ]
    ] ],
    [ "jsSubOptions", "structjs_sub_options.html", [
      [ "Stream", "structjs_sub_options.html#a856a6af4a7ff5aa2e736338091e69484", null ],
      [ "Consumer", "structjs_sub_options.html#a7aa5b8439ed288b858943f28c291cb36", null ],
      [ "Queue", "structjs_sub_options.html#aaf4b620d112a31f51a20389c5405805d", null ],
      [ "ManualAck", "structjs_sub_options.html#a21a905c49dfab61729d8674702d196b2", null ],
      [ "Config", "structjs_sub_options.html#acab25d71a2efe26bb3b084071435c2b5", null ],
      [ "Ordered", "structjs_sub_options.html#a95c5d2db8ca97d644042d436de119be4", null ]
    ] ],
    [ "jsSequencePair", "structjs_sequence_pair.html", [
      [ "Consumer", "structjs_sequence_pair.html#a6d205effd29f8994f0028bfaf2e8d816", null ],
      [ "Stream", "structjs_sequence_pair.html#ab051e0815302c48ba6122bd18d9d76f7", null ]
    ] ],
    [ "jsSequenceInfo", "structjs_sequence_info.html", [
      [ "Consumer", "structjs_sequence_info.html#ae4416a5d766e07db207e563668edd06f", null ],
      [ "Stream", "structjs_sequence_info.html#ab52c55c1d0edd20e064870b490b4b990", null ],
      [ "Last", "structjs_sequence_info.html#a4e94c91650b7db253645515fee4c3b05", null ]
    ] ],
    [ "jsConsumerInfo", "structjs_consumer_info.html", [
      [ "Stream", "structjs_consumer_info.html#a8f21939613163a7c0ebfb521aa471260", null ],
      [ "Name", "structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008", null ],
      [ "Created", "structjs_consumer_info.html#a670d38f2e9ba5c354ca3560a8064d00c", null ],
      [ "Config", "structjs_consumer_info.html#a2f63940ca1f024ad3840418c2f6a1ae1", null ],
      [ "Delivered", "structjs_consumer_info.html#a15f2d68fbf126acc1907ba9462ad9ee9", null ],
      [ "AckFloor", "structjs_consumer_info.html#ab69c36ae092df9b0663b675a5abbab55", null ],
      [ "NumAckPending", "structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50", null ],
      [ "NumRedelivered", "structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001", null ],
      [ "NumWaiting", "structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0", null ],
      [ "NumPending", "structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b", null ],
      [ "Cluster", "structjs_consumer_info.html#a6f4401563a9fd102226d82cdc6136e32", null ],
      [ "PushBound", "structjs_consumer_info.html#a31282cdc72000a91af03f89899740bfa", null ],
      [ "Paused", "structjs_consumer_info.html#a13f80f4b24da173ef2da051e69f216d7", null ],
      [ "PauseRemaining", "structjs_consumer_info.html#a86501e735531929add3e161d40479c44", null ]
    ] ],
    [ "jsConsumerInfoList", "structjs_consumer_info_list.html", [
      [ "List", "structjs_consumer_info_list.html#a75354882af5e11959b198a70bde14db8", null ],
      [ "Count", "structjs_consumer_info_list.html#a813c908362a6426a929133f7c0d3395f", null ]
    ] ],
    [ "jsConsumerNamesList", "structjs_consumer_names_list.html", [
      [ "List", "structjs_consumer_names_list.html#aa4b3cf17902a2d580cc3a230bfa5d309", null ],
      [ "Count", "structjs_consumer_names_list.html#a0bccbad8ac5d335a0ed89970a58900fb", null ]
    ] ],
    [ "jsConsumerPauseResponse", "structjs_consumer_pause_response.html", [
      [ "Paused", "structjs_consumer_pause_response.html#a5ffb8a5073ee4ccf88ae4c634a5c5984", null ],
      [ "PauseUntil", "structjs_consumer_pause_response.html#a7315c1b69c9134d214b5307b58e9cbbe", null ],
      [ "PauseRemaining", "structjs_consumer_pause_response.html#a3264f6817caad99f8578fb41c50a726e", null ]
    ] ],
    [ "jsAPIStats", "structjs_a_p_i_stats.html", [
      [ "Total", "structjs_a_p_i_stats.html#a1545170bebb347d0ea1254f51c3027cf", null ],
      [ "Errors", "structjs_a_p_i_stats.html#a84e85ad9d94dbe9afd1101388574255d", null ]
    ] ],
    [ "jsAccountLimits", "structjs_account_limits.html", [
      [ "MaxMemory", "structjs_account_limits.html#a7bfc63e6f49ce724663ee534c5efdfa4", null ],
      [ "MaxStore", "structjs_account_limits.html#a6fff014c46739410ecf298b0cf643b30", null ],
      [ "MaxStreams", "structjs_account_limits.html#a4710a10950857a322c2a3ad6f946ded2", null ],
      [ "MaxConsumers", "structjs_account_limits.html#a6169f29101d51d48eed0803b719e6338", null ],
      [ "MaxAckPending", "structjs_account_limits.html#a4abf1972690c20d73bd314f2059e8013", null ],
      [ "MemoryMaxStreamBytes", "structjs_account_limits.html#a38875d969274b0f0fcefc6b04ce56eb8", null ],
      [ "StoreMaxStreamBytes", "structjs_account_limits.html#a8cca06ab72b715c02a6a2c72b59f6a52", null ],
      [ "MaxBytesRequired", "structjs_account_limits.html#a858edf99ee1c60354bdba4e59293fb6a", null ]
    ] ],
    [ "jsTier", "structjs_tier.html", [
      [ "Name", "structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6", null ],
      [ "Memory", "structjs_tier.html#aeff4a4cb86e10d8d7749d6ff69f97ed1", null ],
      [ "Store", "structjs_tier.html#ab16c426e1c35d8c0fd6c460c43580a39", null ],
      [ "Streams", "structjs_tier.html#a3f9234fde387faf3775d841aa797a6ea", null ],
      [ "Consumers", "structjs_tier.html#ac33ce862c041572d10184e7fa0dd0bfe", null ],
      [ "Limits", "structjs_tier.html#af2edbabd5e078b1e31dd73d44fd507d3", null ]
    ] ],
    [ "jsAccountInfo", "structjs_account_info.html", [
      [ "Memory", "structjs_account_info.html#a448578d621e878267ad5f1792002a665", null ],
      [ "Store", "structjs_account_info.html#ad1c254c5b8f11f57062a4e2d5fb10ae3", null ],
      [ "Streams", "structjs_account_info.html#a17317abf03effdcdedc2003fca8adc71", null ],
      [ "Consumers", "structjs_account_info.html#a1237c3f19a42a3203825971b429312e9", null ],
      [ "Domain", "structjs_account_info.html#ab6ba03298e1863132550b9b08d06048c", null ],
      [ "API", "structjs_account_info.html#a94ab71c69b7883c2731ae8741ddc1e94", null ],
      [ "Limits", "structjs_account_info.html#aad93cf4bb6c1fbb09ae8545c03f315a9", null ],
      [ "Tiers", "structjs_account_info.html#ab654d5c7456bb62df1808deb32a620fc", null ],
      [ "TiersLen", "structjs_account_info.html#a21c14ca283400c684b18e61a534b6724", null ]
    ] ],
    [ "jsMsgMetaData", "structjs_msg_meta_data.html", [
      [ "Sequence", "structjs_msg_meta_data.html#a23d5fd1992033164c73d5c2a16a4e321", null ],
      [ "NumDelivered", "structjs_msg_meta_data.html#a9a50965fac061a9728b160702d3f56ff", null ],
      [ "NumPending", "structjs_msg_meta_data.html#a02f1bbd37e9650ed6bfda0210f038e30", null ],
      [ "Timestamp", "structjs_msg_meta_data.html#abab9ed5600a3629ea6d6c78170d7d5e9", null ],
      [ "Stream", "structjs_msg_meta_data.html#a32e2a9438d2dc769f7f64d2f8897abc4", null ],
      [ "Consumer", "structjs_msg_meta_data.html#a6dcc2a442984b0ca070b3d8077192127", null ],
      [ "Domain", "structjs_msg_meta_data.html#a388e38ccea591181436d199dc7c2f8ea", null ]
    ] ],
    [ "jsPubAck", "structjs_pub_ack.html", [
      [ "Stream", "structjs_pub_ack.html#a4fd5e6cdb7217d72c553afcc75358893", null ],
      [ "Sequence", "structjs_pub_ack.html#a01d302d5e1a2e71487a8c74c3fed1691", null ],
      [ "Domain", "structjs_pub_ack.html#a0b73200c0b035db3c9c96421706d51b0", null ],
      [ "Duplicate", "structjs_pub_ack.html#a0381a49ff62e8fac7a52cad6a5eb7243", null ]
    ] ],
    [ "jsPubAckErr", "structjs_pub_ack_err.html", [
      [ "Msg", "structjs_pub_ack_err.html#a156ca2f779d132ffa8c519124cf9739b", null ],
      [ "Err", "structjs_pub_ack_err.html#a406e39e818f93bc59ac18cbdf035baf5", null ],
      [ "ErrCode", "structjs_pub_ack_err.html#aa558fd192cc6d6c02ad891445ec5aa8a", null ],
      [ "ErrText", "structjs_pub_ack_err.html#ad1a85e6ff4046d7df33c1e24323ddc87", null ]
    ] ],
    [ "jsDirectGetMsgOptions", "structjs_direct_get_msg_options.html", [
      [ "Sequence", "structjs_direct_get_msg_options.html#a60211d7499cfecdd6e61e6c73af1a2f5", null ],
      [ "NextBySubject", "structjs_direct_get_msg_options.html#a16ce7908a3d1690b8ae8bc22350ac238", null ],
      [ "LastBySubject", "structjs_direct_get_msg_options.html#aae968f31cdda96fa3c5e9374a36b9630", null ]
    ] ],
    [ "jsFetchRequest", "structjs_fetch_request.html", [
      [ "Expires", "structjs_fetch_request.html#ac3351138ce8ac3b321ac1eb78887116e", null ],
      [ "Batch", "structjs_fetch_request.html#a84f06b60e25decb2674996f0cb315f63", null ],
      [ "MaxBytes", "structjs_fetch_request.html#a3298db691c2ecb9725cc029e2c35d6d1", null ],
      [ "NoWait", "structjs_fetch_request.html#ae251eebb1998a39fe3b898302b58293d", null ],
      [ "Heartbeat", "structjs_fetch_request.html#ae8e73c7cc2e2a2d2502407c9b1522496", null ]
    ] ],
    [ "jsOptions", "structjs_options.html", [
      [ "jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", [
        [ "MaxPending", "structjs_options_1_1js_options_publish_async.html#add8dd21cbab2d5df19688c26365fe4d1", null ],
        [ "AckHandler", "structjs_options_1_1js_options_publish_async.html#a508140119f40a2c056d4ee8c0cd55df9", null ],
        [ "AckHandlerClosure", "structjs_options_1_1js_options_publish_async.html#a60c95f10797c04ea2e625759c6936ec9", null ],
        [ "ErrHandler", "structjs_options_1_1js_options_publish_async.html#a0a180995c49990ca277e449b7d43616b", null ],
        [ "ErrHandlerClosure", "structjs_options_1_1js_options_publish_async.html#a784a0029c30e82ff37c39ae6c276bc81", null ],
        [ "StallWait", "structjs_options_1_1js_options_publish_async.html#ada58fefe0ed40157b5f5d44b9dd175f9", null ]
      ] ],
      [ "jsOptionsPullSubscribeAsync", "structjs_options_1_1js_options_pull_subscribe_async.html", [
        [ "Timeout", "structjs_options_1_1js_options_pull_subscribe_async.html#ac103bcfa6982dbd201b511d488b2ce0a", null ],
        [ "MaxMessages", "structjs_options_1_1js_options_pull_subscribe_async.html#a3764380946087ba94d76ed8ab939c52f", null ],
        [ "MaxBytes", "structjs_options_1_1js_options_pull_subscribe_async.html#a0917f86c64293e9abfb6643de219eda4", null ],
        [ "NoWait", "structjs_options_1_1js_options_pull_subscribe_async.html#a2a1d9185656fa87de3e75bebc5ab2f8a", null ],
        [ "CompleteHandler", "structjs_options_1_1js_options_pull_subscribe_async.html#aba9c4dd2abadffd5830cf55b0bc445da", null ],
        [ "CompleteHandlerClosure", "structjs_options_1_1js_options_pull_subscribe_async.html#aeb22dc426a7b8c99ea4ed1f91b27d0a4", null ],
        [ "Heartbeat", "structjs_options_1_1js_options_pull_subscribe_async.html#a30244e22126c588b4a18c6dc23a146d9", null ],
        [ "FetchSize", "structjs_options_1_1js_options_pull_subscribe_async.html#a3f6f91deb357cc43d0d32c1dad7afd9b", null ],
        [ "KeepAhead", "structjs_options_1_1js_options_pull_subscribe_async.html#afd980b44d5bf03ef7abc7fbdd47beca2", null ],
        [ "NextHandler", "structjs_options_1_1js_options_pull_subscribe_async.html#a7b3dfaccb41ffb464df0f3c606313894", null ],
        [ "NextHandlerClosure", "structjs_options_1_1js_options_pull_subscribe_async.html#ab6f9872cd840bafa3a8d73b267ffdeb9", null ]
      ] ],
      [ "jsOptionsStream", "structjs_options_1_1js_options_stream.html", [
        [ "jsOptionsStreamInfo", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html", [
          [ "DeletedDetails", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html#a73f847afe18f56eaaf6788900270bef7", null ],
          [ "SubjectsFilter", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html#af874e0f5aa15fb2a41504631ed786e6d", null ]
        ] ],
        [ "jsOptionsStreamPurge", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html", [
          [ "Subject", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#aa99e6ee3bef1c22243f01544181315fe", null ],
          [ "Sequence", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a0d61e5d3c9c518f455549086ababe7f6", null ],
          [ "Keep", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html#a882c1ce1e636817450893caa72aa4eda", null ]
        ] ],
        [ "Purge", "structjs_options_1_1js_options_stream.html#afe680264223b434ca6959f9e122af029", null ],
        [ "Info", "structjs_options_1_1js_options_stream.html#a2ca89c298b4df1f5e3e0a44e205c789c", null ]
      ] ],
      [ "Prefix", "structjs_options.html#ab06e45296fccf0fe6152e083e38d916f", null ],
      [ "Domain", "structjs_options.html#ae4df6c9c01c0ea9ab0e6d5a6ec8af74e", null ],
      [ "Wait", "structjs_options.html#a7fd42e1f83da5861e716137c16f8b72f", null ],
      [ "PublishAsync", "structjs_options.html#a5ce5c11cc9b9df2b6bc47cd77d7b1dc4", null ],
      [ "PullSubscribeAsync", "structjs_options.html#a4b45e29dc5065528595bea3fd3b9d818", null ],
      [ "Stream", "structjs_options.html#ae50544ee0ef8dd7d02ef9802805807ae", null ]
    ] ],
    [ "kvConfig", "structkv_config.html", [
      [ "Bucket", "structkv_config.html#a11b636da727c17566d5ab1274f69fee5", null ],
      [ "Description", "structkv_config.html#a941e9cad2bab67f093bf4d9567b4749a", null ],
      [ "MaxValueSize", "structkv_config.html#a281156a9df0130abad7f3b2728ac35a5", null ],
      [ "History", "structkv_config.html#a0ec6b3afbfdaa33436e2ae748e986e98", null ],
      [ "TTL", "structkv_config.html#ad2f5503e2f2522cb52e0ba1b86983dba", null ],
      [ "MaxBytes", "structkv_config.html#a1bc37777aa91b8b57a70e7647670cd12", null ],
      [ "StorageType", "structkv_config.html#ad5db9a58224d93ab86b4cfc4c46f1897", null ],
      [ "Replicas", "structkv_config.html#a48f0f70383eff868321f9c94ae1a87cd", null ],
      [ "RePublish", "structkv_config.html#ae172d3e442eef1a57cd7cf266d9e8951", null ],
      [ "Mirror", "structkv_config.html#ac86ca661d283627bccecf70cd286c8f8", null ],
      [ "Sources", "structkv_config.html#afbfd6725c0b0c9fb661a96c06d788ac9", null ],
      [ "SourcesLen", "structkv_config.html#af1d95d5434b10e929d6ce6fa6129a789", null ]
    ] ],
    [ "kvWatchOptions", "structkv_watch_options.html", [
      [ "IgnoreDeletes", "structkv_watch_options.html#a0535edd21b26affc0057575bafc21a07", null ],
      [ "IncludeHistory", "structkv_watch_options.html#a08274f08ae96e14d9ded326e4e665649", null ],
      [ "MetaOnly", "structkv_watch_options.html#ac9094bce4f3c6513431ba32fb49e5605", null ],
      [ "Timeout", "structkv_watch_options.html#a56183d56585697d058c7eeb20bdddb66", null ]
    ] ],
    [ "kvPurgeOptions", "structkv_purge_options.html", [
      [ "Timeout", "structkv_purge_options.html#a245c2def0f3aabe617219772cf7680a8", null ],
      [ "DeleteMarkersOlderThan", "structkv_purge_options.html#a47fed1e95073666cbe441aba7c149da6", null ]
    ] ],
    [ "kvEntryList", "structkv_entry_list.html", [
      [ "Entries", "structkv_entry_list.html#a179d4d3e5844d005be1ed9134b969a50", null ],
      [ "Count", "structkv_entry_list.html#a82da55d42e1a6862d3b0034dfc6f321f", null ]
    ] ],
    [ "kvKeysList", "structkv_keys_list.html", [
      [ "Keys", "structkv_keys_list.html#aa5cb40820a1a927375215e0a94ecfc18", null ],
      [ "Count", "structkv_keys_list.html#a625f7b34784e024a538359efd9a97265", null ]
    ] ],
    [ "natsConnection", "group__types_group.html#gaf88dca0a18efb5c5e994d265a9f04aec", null ],
    [ "natsStatistics", "group__types_group.html#ga57a4b8c7109e2773878655722ce028aa", null ],
    [ "natsSubscription", "group__types_group.html#ga87158ec63b4f90f69e20451624ea01d8", null ],
    [ "natsMsg", "group__types_group.html#gadcab54026c4ed78f344ce03ce31bb61a", null ],
    [ "natsOptions", "group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e", null ],
    [ "natsInbox", "group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1", null ],
    [ "natsClientConfig", "group__types_group.html#gad29b6af20b875a1b7890ab8f0675287d", null ],
    [ "natsMsgList", "group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b", null ],
    [ "natsMetadata", "group__types_group.html#ga3b454f3c6ac697a3cdc5bdd3c9ece12b", null ],
    [ "jsCtx", "group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1", null ],
    [ "jsPubOptions", "group__types_group.html#ga7bbea3575d35dcdbfc9b766b04269eb7", null ],
    [ "jsPlacement", "group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9", null ],
    [ "jsExternalStream", "group__types_group.html#gaef6601477f6456bebc229f7f38982a6c", null ],
    [ "jsStreamSource", "group__types_group.html#gab4c43c87d81917aab748a50eee028449", null ],
    [ "jsRePublish", "group__types_group.html#gab991313d33ce270a882e4d0756c138f6", null ],
    [ "jsSubjectTransformConfig", "group__types_group.html#gac3148248f38749f6ba70471b7a6b96e1", null ],
    [ "jsStreamConsumerLimits", "group__types_group.html#gadb76a02c18655461dbd3ee266502338c", null ],
    [ "jsStreamConfig", "group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf", null ],
    [ "jsLostStreamData", "group__types_group.html#gaf80828510450faf84bbf456e94f5b784", null ],
    [ "jsStreamStateSubject", "group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa", null ],
    [ "jsStreamStateSubjects", "group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0", null ],
    [ "jsStreamState", "group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271", null ],
    [ "jsPeerInfo", "group__types_group.html#ga1e938dab794089f9329d7b7ece8f3e9b", null ],
    [ "jsClusterInfo", "group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6", null ],
    [ "jsStreamSourceInfo", "group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd", null ],
    [ "jsStreamAlternate", "group__types_group.html#ga22c26dd5dd31df7982130ef203ad3490", null ],
    [ "jsStreamInfo", "group__types_group.html#ga2629c9454996edf7914be36a9e44921b", null ],
    [ "jsStreamInfoList", "group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565", null ],
    [ "jsStreamNamesList", "group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000", null ],
    [ "jsConsumerConfig", "group__types_group.html#ga0483b2197c0ddd9082b48c2dd3fe7cee", null ],
    [ "jsConsumerSequenceMismatch", "group__types_group.html#gace471cd2cef1df797b2a1c6b485049bd", null ],
    [ "jsSubOptions", "group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280", null ],
    [ "jsSequencePair", "group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f", null ],
    [ "jsSequenceInfo", "group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003", null ],
    [ "jsConsumerInfo", "group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5", null ],
    [ "jsConsumerInfoList", "group__types_group.html#gadad3bf72baae970662248d82d9b05d0a", null ],
    [ "jsConsumerNamesList", "group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2", null ],
    [ "jsConsumerPauseResponse", "group__types_group.html#gad333f1891809ea7641908e62dcc809ce", null ],
    [ "jsAPIStats", "group__types_group.html#gad057a0107367ce5727975f3daf63ff75", null ],
    [ "jsAccountLimits", "group__types_group.html#gaa889f706cce285adb9cea8aba0b76866", null ],
    [ "jsTier", "group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8", null ],
    [ "jsAccountInfo", "group__types_group.html#ga57cdc53b29a4fedb5a4140b6e64a4fab", null ],
    [ "jsMsgMetaData", "group__types_group.html#gace9595b1a5ce3f7a13670367fd293b4a", null ],
    [ "jsPubAck", "group__types_group.html#gaf1d5e436c5d41c5b9b96d84e3d2bc86f", null ],
    [ "jsPubAckErr", "group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40", null ],
    [ "jsDirectGetMsgOptions", "group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063", null ],
    [ "jsFetchRequest", "group__types_group.html#gaf11e6664c1f335a5287af71c703935fa", null ],
    [ "jsFetchCompleteHandler", "group__types_group.html#gaa17c5b961bcaa3c5907f48366b6e75c4", null ],
    [ "jsFetchNextHandler", "group__types_group.html#ga617d3ea9036a7ef05dd3868fa56abafc", null ],
    [ "jsOptions", "group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5", null ],
    [ "kvStore", "group__types_group.html#ga054c05493dd3cfc5c3e7a665a424e54a", null ],
    [ "kvEntry", "group__types_group.html#gad489fb4074f27427560ca71797db6191", null ],
    [ "kvStatus", "group__types_group.html#gad3a0dd2dac950d5709ee5772b104fc80", null ],
    [ "kvWatcher", "group__types_group.html#ga526fa6d37e818784b94cdc1713f3a043", null ],
    [ "kvConfig", "group__types_group.html#ga6d594b091b4bb46192336413066a8edf", null ],
    [ "kvWatchOptions", "group__types_group.html#gac32f992fe797a1f7befc7dc3452640b6", null ],
    [ "kvPurgeOptions", "group__types_group.html#ga90e8de23c4468005488bde690a2ffe9d", null ],
    [ "kvEntryList", "group__types_group.html#ga0125d394a3cbae2a1713eed8fab7f78e", null ],
    [ "kvKeysList", "group__types_group.html#gab36492d9d4370337cfed80edce4144e0", null ],
    [ "stanConnection", "group__types_group.html#ga9e826493769d23086cfccefe95cdf64c", null ],
    [ "stanSubscription", "group__types_group.html#gae4dae869fb614536f0f027c2e2660cc5", null ],
    [ "stanMsg", "group__types_group.html#ga2cf5db7703b42d97abe56a3e83b2a87d", null ],
    [ "stanConnOptions", "group__types_group.html#ga13d64411878ba13a6ca39c915f2447c1", null ],
    [ "stanSubOptions", "group__types_group.html#ga023712711f5c289663fc2223e83686d3", null ],
    [ "jsRetentionPolicy", "group__types_group.html#ga410f8fb053efa02b2ca1de0c02fa4b6d", [
      [ "js_LimitsPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6da6a2aa02f32acec6526d81f6e974e690f", null ],
      [ "js_InterestPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6dae874de4a787cfbec4c6d0eb1a3f05ebd", null ],
      [ "js_WorkQueuePolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6daf7e6581e69572691b01d1294a3c3a478", null ]
    ] ],
    [ "jsDiscardPolicy", "group__types_group.html#ga7f88b7d482488398074f9d1419a9b8c2", [
      [ "js_DiscardOld", "group__types_group.html#gga7f88b7d482488398074f9d1419a9b8c2abb31b828421634f1e6a1ef9359bc91f6", null ],
      [ "js_DiscardNew", "group__types_group.html#gga7f88b7d482488398074f9d1419a9b8c2a99d7f2d740af26c340c0a4e2b72fb6ab", null ]
    ] ],
    [ "jsStorageType", "group__types_group.html#ga1802a53c79e667f093bba033b16adc98", [
      [ "js_FileStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a1d9dad1854cf374b22e3688b98284dec", null ],
      [ "js_MemoryStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a428ed10448726ad01c1db77a7f748314", null ]
    ] ],
    [ "jsStorageCompression", "group__types_group.html#ga10d2999dc673ed95e131e6ce5181f720", [
      [ "js_StorageCompressionNone", "group__types_group.html#gga10d2999dc673ed95e131e6ce5181f720a97bd071285006dc90dc4600a25f85e89", null ],
      [ "js_StorageCompressionS2", "group__types_group.html#gga10d2999dc673ed95e131e6ce5181f720afab4e3a974823f4438292b2405349d4a", null ]
    ] ],
    [ "jsDeliverPolicy", "group__types_group.html#ga117ed2c35f89ef3144540ed9cbadc818", [
      [ "js_DeliverAll", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818ac692ba1363103768ac4bb58695549758", null ],
      [ "js_DeliverLast", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818abbd81d6c4e0f17f30e2186f1335e991d", null ],
      [ "js_DeliverNew", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a82b8d36e17391212398984f92db9c381", null ],
      [ "js_DeliverByStartSequence", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a06299d9c8262a16306ba6cc16d293c5e", null ],
      [ "js_DeliverByStartTime", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a33317133d42f21bf5919827a691543f6", null ],
      [ "js_DeliverLastPerSubject", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818abb50ebcd2fbafe27038c966121b9407b", null ]
    ] ],
    [ "jsAckPolicy", "group__types_group.html#ga8fcb50e6e7312834791f9e237d28e873", [
      [ "js_AckExplicit", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a02d46a6395933c55c95ee5194bb6b80e", null ],
      [ "js_AckNone", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873afd91fe31cf57c68863ca3090b07c296c", null ],
      [ "js_AckAll", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a1232af28bf4e4b82e962174f1432ed4a", null ]
    ] ],
    [ "jsReplayPolicy", "group__types_group.html#ga8650faf52b0b6b23df376eebeb9d0354", [
      [ "js_ReplayInstant", "group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a2c4a1e2b75f31dd69a89b541d75afa44", null ],
      [ "js_ReplayOriginal", "group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a6ee3851dac5c90a61492193dd55931f5", null ]
    ] ],
    [ "kvOperation", "group__types_group.html#ga89db3bd6bf11af3ac5eb3ab560d16332", [
      [ "kvOp_Unknown", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a0b7a6bef67e4220f5f0c4075f2ed16b6", null ],
      [ "kvOp_Put", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332acc0e1da3c292cb7eb19d909c9dfd788a", null ],
      [ "kvOp_Delete", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a4efb91331f3307128c75af5b23362f83", null ],
      [ "kvOp_Purge", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332aee19ab8144bf518e251ea2004309b657", null ]
    ] ]
];